"""multitenancy Settings"""

"""
|--------------------------------------------------------------------------
| MultiTenancy
|--------------------------------------------------------------------------
|
| Multitenancy is a feature that allows you to have multiple tenants in your
| application. This is useful for things like a company having multiple
| websites, or a company having multiple apps.
|
"""

TENANTS = {}
